@@ -19,12 +19,13 @@ from typing import Any, Dict, List, Optional, Set
 
 from dateutil.parser import parse
 from jsonschema import validate
+
 from rp2.abstract_country import AbstractCountry
 from rp2.configuration_schema import CONFIGURATION_SCHEMA
 from rp2.rp2_decimal import ZERO, RP2Decimal
 from rp2.rp2_error import RP2TypeError, RP2ValueError
 
-VERSION: str = "0.9.11"
+VERSION: str = "0.9.20"
 
 MIN_DATE: date = date(1970, 1, 1)
 MAX_DATE: date = date(9999, 12, 31)
@@ -152,7 +153,7 @@ class Configuration:  # pylint: disable=too-many-public-methods
         if len(data) <= max_column:
             raise RP2ValueError(
                 f"Parameter 'data' has length {len(data)}, but required minimum from {table_type}-table headers in "
-                f"{self.__configuration_path} is {max_column + 1}"
+                f"{self.__configuration_path} is {max_column + 1}: {data}"
             )
         pack: Dict[str, Any] = {argument: data[position] for argument, position in header.items()}
 
@@ -186,7 +187,7 @@ class Configuration:  # pylint: disable=too-many-public-methods
         return self.__intra_header[input_parameter]
 
     @classmethod
-    def type_check_unique_id(cls, name: str, value: int) -> int:
+    def type_check_internal_id(cls, name: str, value: int) -> int:
         return cls.type_check_positive_int(name, value)
 
     @classmethod
