@@ -44,10 +44,11 @@ class InTransaction(AbstractTransaction):
         fiat_fee: RP2Decimal,
         fiat_in_no_fee: Optional[RP2Decimal] = None,
         fiat_in_with_fee: Optional[RP2Decimal] = None,
-        unique_id: Optional[int] = None,
+        internal_id: Optional[int] = None,
+        unique_id: Optional[str] = None,
         notes: Optional[str] = None,
     ) -> None:
-        super().__init__(configuration, timestamp, asset, transaction_type, spot_price, unique_id, notes)
+        super().__init__(configuration, timestamp, asset, transaction_type, spot_price, internal_id, unique_id, notes)
 
         self.__exchange: str = configuration.type_check_exchange("exchange", exchange)
         self.__holder: str = configuration.type_check_holder("holder", holder)
@@ -68,14 +69,16 @@ class InTransaction(AbstractTransaction):
             self.__fiat_in_with_fee = configuration.type_check_positive_decimal("fiat_in_with_fee", fiat_in_with_fee, non_zero=True)
 
         if spot_price == ZERO:
-            raise RP2ValueError(f"{self.asset} {type(self).__name__} ({self.timestamp}, id {self.unique_id}): parameter 'spot_price' cannot be 0")
+            raise RP2ValueError(f"{self.asset} {type(self).__name__} ({self.timestamp}, id {self.internal_id}): parameter 'spot_price' cannot be 0")
         if (
             self.transaction_type != TransactionType.BUY
             and self.transaction_type != TransactionType.GIFT
             and self.transaction_type != TransactionType.DONATE
             and not self.transaction_type.is_earn_type()
         ):
-            raise RP2ValueError(f"{self.asset} {type(self).__name__} ({self.timestamp}, id {self.unique_id}): invalid transaction type {self.transaction_type}")
+            raise RP2ValueError(
+                f"{self.asset} {type(self).__name__} ({self.timestamp}, id {self.internal_id}): invalid transaction type {self.transaction_type}"
+            )
 
         # If the values provided by the exchange doesn't match the computed one, log a warning.
         if not RP2Decimal.is_equal_within_precision(self.__crypto_in * self.spot_price, self.__fiat_in_no_fee, FIAT_DECIMAL_MASK):
@@ -84,7 +87,7 @@ class InTransaction(AbstractTransaction):
                 self.asset,
                 type(self).__name__,
                 self.timestamp,
-                self.unique_id,
+                self.internal_id,
                 self.__crypto_in * self.spot_price,
                 self.__fiat_in_no_fee,
             )
@@ -94,7 +97,7 @@ class InTransaction(AbstractTransaction):
                 self.asset,
                 type(self).__name__,
                 self.timestamp,
-                self.unique_id,
+                self.internal_id,
                 self.__fiat_in_with_fee,
                 self.__fiat_in_no_fee + self.__fiat_fee,
             )
@@ -118,6 +121,7 @@ class InTransaction(AbstractTransaction):
             f"fiat_fee={self.fiat_fee:.4f}",
             f"fiat_in_no_fee={self.fiat_in_no_fee:.4f}",
             f"fiat_in_with_fee={self.fiat_in_with_fee:.4f}",
+            f"unique_id={self.unique_id}",
             f"is_taxable={stringify(self.is_taxable())}",
             f"fiat_taxable_amount={self.fiat_taxable_amount:.4f}",
         ]
